turbogears.widgets.base.MetaDescription

turbogears :: widgets :: base :: MetaDescription :: Class MetaDescription |
[hide private]

# Type MetaDescription

     object --+
              |
           type --+
                  |
    meta.MetaWidget --+
                      |
                     MetaDescription

Metaclass for widget descriptions. Makes sure the widget browser knows about all of them as soon as they come into existence.

Instance Methods | [hide private]
__init__(cls, name, bases, dct) |
Inherited from `type`: `__call__`, `__cmp__`, `__delattr__`, `__getattribute__`, `__hash__`, `__repr__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__reduce__`, `__reduce_ex__`, `__str__`

Static Methods | [hide private]
Inherited from `meta.MetaWidget`: `__new__`

Properties | [hide private]
Inherited from `type`: `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(cls, name, bases, dct) (Constructor) |
Overrides: meta.MetaWidget.__init__